@@ -338,9 +338,9 @@ fit_glance_compute_group_fun <- function(data,
                       left = (0 + margin.npc) +  hsteps
     )
     if (!npc.used) {
-      x.delta <- abs(diff(range(data$x)))
-      x.min <- min(data$x)
-      label.x <- label.x * x.delta + x.min
+      # we need to use scale limits as observations are not necessarily plotted
+      x.range <- scales$x$range$range
+      label.x <- label.x * diff(x.range) + x.range[1]
     }
   }
 
@@ -354,9 +354,9 @@ fit_glance_compute_group_fun <- function(data,
                       bottom = (0 + margin.npc) + vsteps
     )
     if (!npc.used) {
-      y.delta <- abs(diff(range(data$y)))
-      y.min <- min(data$y)
-      label.y <- label.y * y.delta + y.min
+      # we need to use scale limits as observations are not necessarily plotted
+      y.range <- scales$y$range$range
+      label.y <- label.y * diff(y.range) + y.range[1]
     }
   }
   if (npc.used) {
@@ -1036,9 +1036,9 @@ fit_tidy_compute_group_fun <- function(data,
                       left = (0 + margin.npc) +  hsteps
     )
     if (!npc.used) {
-      x.delta <- abs(diff(range(data$x)))
-      x.min <- min(data$x)
-      label.x <- label.x * x.delta + x.min
+      # we need to use scale limits as observations are not necessarily plotted
+      x.range <- scales$x$range$range
+      label.x <- label.x * diff(x.range) + x.range[1]
     }
   }
 
@@ -1052,9 +1052,9 @@ fit_tidy_compute_group_fun <- function(data,
                       bottom = (0 + margin.npc) + vsteps
     )
     if (!npc.used) {
-      y.delta <- abs(diff(range(data$y)))
-      y.min <- min(data$y)
-      label.y <- label.y * y.delta + y.min
+      # we need to use scale limits as observations are not necessarily plotted
+      y.range <- scales$y$range$range
+      label.y <- label.y * diff(y.range) + y.range[1]
     }
   }
   if (npc.used) {
