@@ -30,6 +30,8 @@
 #'   parameters \code{formula}, \code{data}, \code{weights} and \code{method}. A
 #'   \code{fitted()} method must exist for the returned model fit object class.
 #' @param method.args named list with additional arguments.
+#' @param n.min integer Minimum number of distinct values in the explanatory
+#'   variable (on the rhs of formula) for fitting to the attempted.
 #' @param formula a "formula" object. Using aesthetic names instead of
 #'   original variable names.
 #' @param orientation character Either "x" or "y" controlling the default for
@@ -57,7 +59,7 @@
 #'
 #' @section Computed variables: Data frame with same \code{nrow} as \code{data}
 #'   as subset for each group containing five numeric variables. \describe{
-#'   \item{x}{x coordinates of observations} \item{y.fitted}{x coordinates of
+#'   \item{x}{x coordinates of observations} \item{x.fitted}{x coordinates of
 #'   fitted values} \item{y}{y coordinates of observations} \item{y.fitted}{y
 #'   coordinates of fitted values}}
 #'
@@ -172,6 +174,7 @@
 stat_fit_deviations <- function(mapping = NULL, data = NULL, geom = "segment",
                                method = "lm",
                                method.args = list(),
+                               n.min = 2L,
                                formula = NULL,
                                position = "identity",
                                na.rm = FALSE,
@@ -184,6 +187,7 @@ stat_fit_deviations <- function(mapping = NULL, data = NULL, geom = "segment",
     params =
       rlang::list2(method = method,
                    method.args = method.args,
+                   n.min = n.min,
                    formula = formula,
                    na.rm = na.rm,
                    orientation = orientation,
@@ -202,6 +206,7 @@ deviations_compute_group_fun <- function(data,
                                          scales,
                                          method,
                                          method.args,
+                                         n.min,
                                          formula,
                                          orientation) {
   stopifnot(!any(c("formula", "data") %in% names(method.args)))
@@ -222,6 +227,16 @@ deviations_compute_group_fun <- function(data,
     orientation <- unname(c(x = "y", y = "x")[as.character(formula)[2]])
   }
 
+  if (orientation == "x") {
+    if (length(unique(data$x)) < n.min) {
+      return(data.frame())
+    }
+  } else if (orientation == "y") {
+    if (length(unique(data$y)) < n.min) {
+      return(data.frame())
+    }
+  }
+
   # If method was specified as a character string, replace with
   # the corresponding function. Some model fit functions themselves have a
   # method parameter accepting character strings as argument. We support
@@ -318,3 +333,153 @@ StatFitDeviations <-
                                   yend = after_stat(y.fitted)),
                    required_aes = c("x", "y")
   )
+
+#' @rdname stat_fit_deviations
+#'
+#' @export
+#'
+stat_fit_fitted <- function(mapping = NULL, data = NULL, geom = "point",
+                            method = "lm",
+                            method.args = list(),
+                            n.min = 2L,
+                            formula = NULL,
+                            position = "identity",
+                            na.rm = FALSE,
+                            orientation = NA,
+                            show.legend = FALSE,
+                            inherit.aes = TRUE, ...) {
+  ggplot2::layer(
+    stat = StatFitFitted, data = data, mapping = mapping, geom = geom,
+    position = position, show.legend = show.legend, inherit.aes = inherit.aes,
+    params =
+      rlang::list2(method = method,
+                   method.args = method.args,
+                   n.min = n.min,
+                   formula = formula,
+                   na.rm = na.rm,
+                   orientation = orientation,
+                   ...)
+  )
+}
+
+# Define here to avoid a note in check as the imports are not seen by checks
+# when the function is defined in-line in the ggproto object.
+#' @rdname ggpmisc-ggproto
+#'
+#' @format NULL
+#' @usage NULL
+#'
+fitted_compute_group_fun <- function(data,
+                                     scales,
+                                     method,
+                                     method.args,
+                                     n.min,
+                                     formula,
+                                     orientation,
+                                     return.fitted = FALSE) {
+  stopifnot(!any(c("formula", "data") %in% names(method.args)))
+  if (is.null(data$weight)) {
+    data$weight <- 1
+  }
+
+  # we guess formula from orientation
+  if (is.null(formula)) {
+    if (is.na(orientation) || orientation == "x") {
+      formula = y ~ x
+    } else if (orientation == "y") {
+      formula = x ~ y
+    }
+  }
+  # we guess orientation from formula
+  if (is.na(orientation)) {
+    orientation <- unname(c(x = "y", y = "x")[as.character(formula)[2]])
+  }
+
+  if (orientation == "x") {
+    if (length(unique(data$x)) < n.min) {
+      return(data.frame())
+    }
+  } else if (orientation == "y") {
+    if (length(unique(data$y)) < n.min) {
+      return(data.frame())
+    }
+  }
+
+  # If method was specified as a character string, replace with
+  # the corresponding function. Some model fit functions themselves have a
+  # method parameter accepting character strings as argument. We support
+  # these by splitting strings passed as argument at a colon.
+  if (is.character(method)) {
+    method <- switch(method,
+                     lm = "lm:qr",
+                     rlm = "rlm:M",
+                     lqs = "lqs:lts",
+                     rq = "rq:br",
+                     method)
+    method.name <- method
+    method <- strsplit(x = method, split = ":", fixed = TRUE)[[1]]
+    if (length(method) > 1L) {
+      fun.method <- method[2]
+      method <- method[1]
+    } else {
+      fun.method <- character()
+    }
+    if (method == "rq") {
+      rlang::check_installed("quantreg", reason = "for `stat_fit_deviations()` with method `rq()`")
+    }
+
+    method <- switch(method,
+                     lm = stats::lm,
+                     rlm = MASS::rlm,
+                     lqs = MASS::lqs,
+                     rq = quantreg::rq,
+                     match.fun(method))
+  } else if (is.function(method)) {
+    fun.method <- character()
+    if (is.name(quote(method))) {
+      method.name <- as.character(quote(method))
+    } else {
+      method.name <- "function"
+    }
+  }
+
+  fun.args <- list(quote(formula),
+                   data = quote(data),
+                   weights = data[["weight"]])
+  fun.args <- c(fun.args, method.args)
+  if (length(fun.method)) {
+    fun.args[["method"]] <- fun.method
+  }
+
+  # quantreg contains code with partial matching of names!
+  # so we silence selectively only these warnings
+  withCallingHandlers({
+    fm <- do.call(method, args = fun.args)
+  }, warning = function(w) {
+    if (startsWith(conditionMessage(w), "partial match of") ||
+        startsWith(conditionMessage(w), "partial argument match of")) {
+      invokeRestart("muffleWarning")
+    }
+  })
+
+  fitted.vals <- stats::fitted(fm)
+  if (orientation == "y") {
+    data.frame(x = fitted.vals,
+               y = data$y)
+  } else {
+    data.frame(x = data$x,
+               y = fitted.vals)
+  }
+}
+
+#' @rdname ggpmisc-ggproto
+#' @format NULL
+#' @usage NULL
+#'
+#' @export
+#'
+StatFitFitted <-
+  ggplot2::ggproto("StatFitFitted", ggplot2::Stat,
+                   compute_group = fitted_compute_group_fun,
+                   required_aes = c("x", "y")
+  )
