@@ -31,6 +31,8 @@
 #'   \code{residuals()} method must exist for the returned model fit object
 #'   class.
 #' @param method.args named list with additional arguments.
+#' @param n.min integer Minimum number of distinct values in the explanatory
+#'   variable (on the rhs of formula) for fitting to the attempted.
 #' @param formula a "formula" object. Using aesthetic names instead of
 #'   original variable names.
 #' @param resid.type character passed to \code{residuals()} as argument for
@@ -171,6 +173,7 @@ stat_fit_residuals <- function(mapping = NULL,
                                geom = "point",
                                method = "lm",
                                method.args = list(),
+                               n.min = 2L,
                                formula = NULL,
                                resid.type = NULL,
                                weighted = FALSE,
@@ -185,6 +188,7 @@ stat_fit_residuals <- function(mapping = NULL,
     params =
       rlang::list2(method = method,
                    method.args = method.args,
+                   n.min = n.min,
                    formula = formula,
                    resid.type = resid.type,
                    weighted = weighted,
@@ -203,6 +207,7 @@ residuals_compute_group_fun <- function(data,
                                         scales,
                                         method,
                                         method.args,
+                                        n.min,
                                         formula,
                                         resid.type,
                                         weighted,
@@ -225,6 +230,16 @@ residuals_compute_group_fun <- function(data,
     orientation <- unname(c(x = "y", y = "x")[as.character(formula)[2]])
   }
 
+  if (orientation == "x") {
+    if (length(unique(data$x)) < n.min) {
+      return(data.frame())
+    }
+  } else if (orientation == "y") {
+    if (length(unique(data$y)) < n.min) {
+      return(data.frame())
+    }
+  }
+
   # If method was specified as a character string, replace with
   # the corresponding function. Some model fit functions themselves have a
   # method parameter accepting character strings as argument. We support
